=========
Tutorials
=========

The tutorials are designed to get you quickly started.
It is assumed, that the tutorials are used together 
with the user guide. The user guide is way more texty, 
while the tutorials are focused on code.

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    01_getting_started
    02_variogram_models
    03_estimators
    04_Plotting
    05_binning
    06_gstools